"use strict";

var interpreters = require("./poll");
var cmds = require("../cmds");

var _require = require("effects-as-data/core"),
    call = _require.call;

var _require2 = require("object-path-immutable"),
    set = _require2.set;

test("poll() should poll until tryCount is reached", function () {
  var _marked = [foo].map(regeneratorRuntime.mark);

  function foo(ctx) {
    return regeneratorRuntime.wrap(function foo$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", set(ctx, "count", (ctx.count || 0) + 1));

          case 1:
          case "end":
            return _context.stop();
        }
      }
    }, _marked[0], this);
  }
  return interpreters.poll(cmds.poll(foo, {}, 100, 3), {
    context: {},
    call: call,
    interpreters: {}
  }).then(function (ctx) {
    expect(ctx.count).toEqual(3);
  });
});

test("poll() should abort if done is true", function () {
  var _marked2 = [foo].map(regeneratorRuntime.mark);

  var count = 0;
  function foo(ctx) {
    return regeneratorRuntime.wrap(function foo$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            count++;
            return _context2.abrupt("return", set(ctx, "done", true));

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _marked2[0], this);
  }
  return interpreters.poll(cmds.poll(foo, {}, 1), {
    context: {},
    call: call,
    interpreters: {}
  }).then(function (ctx) {
    expect(count).toEqual(1);
  });
});

test("clearPoll() should clear interval", function () {
  var _marked3 = [foo].map(regeneratorRuntime.mark);

  var count = 0;
  function foo(ctx, id) {
    return regeneratorRuntime.wrap(function foo$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            count++;

            if (!(count === 5)) {
              _context3.next = 4;
              break;
            }

            _context3.next = 4;
            return cmds.clearPoll(id);

          case 4:
            return _context3.abrupt("return", ctx);

          case 5:
          case "end":
            return _context3.stop();
        }
      }
    }, _marked3[0], this);
  }
  return interpreters.poll(cmds.poll(foo, {}, 1, 100), {
    context: {},
    call: call,
    interpreters: interpreters
  }).then(function (ctx) {
    expect(count).toEqual(5);
  });
});

test("poll() should handle error in function", function () {
  var _marked4 = [foo].map(regeneratorRuntime.mark);

  var count = 0;
  function foo(ctx) {
    return regeneratorRuntime.wrap(function foo$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            throw new Error("oops");

          case 1:
          case "end":
            return _context4.stop();
        }
      }
    }, _marked4[0], this);
  }
  return interpreters.poll(cmds.poll(foo, {}, 1), {
    context: {},
    call: call,
    interpreters: {}
  }).then(function () {
    fail("should have thrown");
  }).catch(function (e) {
    expect(e.message).toEqual("oops");
  });
});
//# sourceMappingURL=poll.spec.js.map